@@ -8,6 +8,7 @@ from pdf2image import convert_from_path
 from dataclasses import dataclass, field
 from werkzeug.utils import secure_filename
 from werkzeug.datastructures import FileStorage
-import fnmatch, fnmatch,shlex, os, glob, platform, textwrap, pkgutil
+import fnmatch, fnmatch,shlex, os, glob, platform, textwrap, pkgutil,time
 import tempfile,shutil,logging,ezodf,fnmatch,pytesseract,pdfplumber,re
 import textwrap, sys, types, importlib, importlib.util, inspect,PyPDF2
+
